[Bug middle-end/84040] [8 regression] compilation time of gcc.c-torture/compile/limits-blockid.c is 50x slower
jakub at gcc dot gnu.org
gcc-bugzilla@gcc.gnu.org
Fri Jan 26 15:11:00 GMT 2018
https://gcc.gnu.org/bugzilla/show_bug.cgi?id=84040
Jakub Jelinek <jakub at gcc dot gnu.org> changed:
What |Removed |Added
----------------------------------------------------------------------------
CC| |jakub at gcc dot gnu.org
--- Comment #3 from Jakub Jelinek <jakub at gcc dot gnu.org> ---
So, instead of no insns at all wqe have 100000 debug markers in a single bb and
nothing else. So some slowdown is completely justified.
The 2 minutes looks weird, even -O0 built cc1 on x86_64 takes just 1:10 minute
to compile it, with a single pass that takes most time:
scheduling 2 : 55.89 (85%) usr 0.02 ( 5%) sys 56.00 (84%) wall
3908 kB ( 2%) ggc
With RTL checking but optimized x86_64 cc1:
scheduling 2 : 17.95 (90%) usr 0.01 ( 2%) sys 17.99 (86%) wall
3908 kB ( 2%) ggc
So something is wrong during sched2.
More information about the Gcc-bugs
mailing list